@@ -542,3 +542,45 @@ json_window = {
     "where_string": "sales_price BETWEEN 1000 AND 1050",
     "order_by": ['pg.name']
 }
+
+json = {
+    "schema_name": "lc",
+    "table_name": "products_product",
+    "select": ["prodgroup.code", "prodgroup.name"],
+    "total": [
+        {
+            "action": "sum",
+            "column": "sales_price",
+            "alias": "",
+            "having": "> 10000",
+            "order_by": "desc"
+        },
+        {
+            "action": "avg",
+            "column": "sales_price",
+            "alias": "average",
+            "having": "",
+            "order_by": ""
+        },
+    ],
+    "cube": ["prodgroup.name"],
+    "left_join": [
+        {
+            "schema_name": "lc",
+            "table_name": "products_productgroup",
+            "alias": "prodgroup",
+            "relation": "product_group"
+            # "on": "prpr.product_group = prodgroup.id"
+        }
+    ],
+    "where": [
+        {
+            "sales_price__gt": 4000,
+            "sales_price__lte": 6000
+        }
+    ]
+}
+
+# q = AGQueryPostgres()
+# result = q.explain(json)
+# print(result)
\ No newline at end of file
